##  Overview
In the ServiceNow integration, relations between applications and hardware or software items are configured differently from other relations. This specialized setup allows for more precise identification, leading to more accurate results and faster synchronization. Previously, the default setup considered all relations in the cmdb_rel_ci table, regardless of type or whether they connected directly or indirectly (through other records) between application records and hardware instance records. This often resulted in relations between applications and IT components that weren't visible in the ServiceNow view.
When configuring relations between applications and hardware/software items in ServiceNow, set up rules for detecting these relations. These rules are based on the cmdb_rel_ci table, which connects the application table to the hardware instance table (cmdb_ci_hardware).
